@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 1996, 1997, 1998, 1999 Shigio Yamaguchi
- * Copyright (c) 1999, 2000, 2001, 2002, 2003 Tama Communications Corporation
+ * Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003
+ *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -63,11 +63,11 @@ open_dup_file(db, count)
 		snprintf(command, sizeof(command), "gzip -c >%s", path);
 		op = popen(command, "w");
 		if (op == NULL)
-			die("cannot create file '%s'.", path);
+			die("cannot execute command '%s'.", command);
 	} else {
 		op = fopen(path, "w");
 		if (op == NULL)
-			die("cannot execute command '%s'.", command);
+			die("cannot create file '%s'.", path);
 	}
 	return op;
 }
@@ -81,7 +81,7 @@ close_dup_file(op)
 	FILE *op;
 {
 	if (cflag) {
-		if (pclose(op) < 0)
+		if (pclose(op) != 0)
 			die("'%s' failed.", command);
 	} else {
 		fclose(op);
@@ -167,7 +167,12 @@ makedupindex()
 					cache_put(db, prev, buf);
 					recover(&ptable);
 				}
-				strlimcpy(first_line, _, sizeof(first_line));
+				/*
+				 * Chop the tail of the line. It is not important.
+				 * strlimcpy(first_line, _, sizeof(first_line));
+				 */
+				strncpy(first_line, _, sizeof(first_line));
+				first_line[sizeof(first_line) - 1] = '\0';
 				strlimcpy(prev, tag, sizeof(prev));
 				entry_count = 0;
 			} else {
@@ -193,7 +198,7 @@ makedupindex()
 		}
 		if (db == GTAGS)
 			definition_count = count;
-		if (pclose(ip) < 0)
+		if (pclose(ip) != 0)
 			die("'%s' failed.", command);
 		if (writing) {
 			if (!dynamic) {
