@@ -1,7 +1,6 @@
 /*
- * Copyright (c) 1996, 1997, 1998, 1999 Shigio Yamaguchi
- * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004
- *		Tama Communications Corporation
+ * Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004
+ *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -139,7 +138,7 @@ close_file_queue(path)
 	if (file == NULL)
 		die("cannot close no existent file.");
 	if (file->compress) {
-		if (pclose(file->op) < 0) {
+		if (pclose(file->op) != 0) {
 			char command[MAXFILLEN];
 			snprintf(command, sizeof(command), "gzip -c >%s", file->path);
 			die("command '%s' failed.", command);
@@ -712,8 +711,7 @@ makefileindex(file, files)
 				strbuf_sprintf(sb, "<A HREF=%s%s TITLE='%s/'>",
 					count_stack(dirstack) == 1 ? "files/" : "",
 					path2url(path),
-					path,
-					last);
+					path);
 				if (icon_list) {
 					strbuf_sprintf(sb, "<IMG SRC=%sicons/%s.%s ALT=[%s/] HSPACE=3 %s>",
 						count_stack(dirstack) == 1 ? "" : "../", dir_icon, icon_suffix, path, icon_spec);
@@ -831,7 +829,7 @@ makefileindex(file, files)
 	}
 	if (map_file)
 		fclose(FILEMAP);
-	if (pclose(FIND) < 0)
+	if (pclose(FIND) != 0)
 		die("cannot traverse directory.(%s)", command);
 	while (count_stack(dirstack) > 0) {
 		char *parent;
@@ -934,7 +932,7 @@ makeincludeindex()
 		}
 		put_included(last, buf);
 	}
-	if (pclose(PIPE) < 0)
+	if (pclose(PIPE) != 0)
 		die("terminated abnormally.");
 
 	for (inc = first_inc(); inc; inc = next_inc()) {
