@@ -1,7 +1,6 @@
 /*
- * Copyright (c) 1996, 1997, 1998, 1999 Shigio Yamaguchi
- * Copyright (c) 1999, 2000, 2001, 2002, 2003, 2004
- *			Tama Communications Corporation
+ * Copyright (c) 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005
+ *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -23,7 +22,6 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include <fcntl.h>
 #include <stdio.h>
 #ifdef STDC_HEADERS
 #include <stdlib.h>
@@ -31,6 +29,11 @@
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#else
+#include <sys/file.h>
+#endif
 #include <signal.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -103,6 +106,7 @@ int dynamic;				/* --dynamic(-D) option		*/
 int symbol;				/* --symbol(-s) option		*/
 int statistics;				/* --statistics option		*/
 
+int copy_files;				/* 1: copy tag files		*/
 int no_map_file;			/* 1: doesn't make map file	*/
 int no_order_list;			/* 1: doesn't use order list	*/
 int other_files;			/* 1: list other files		*/
@@ -200,7 +204,7 @@ int cgi = 1;				/* 1: make cgi-bin/		*/
 int definition_header=NO_HEADER;	/* (NO|BEFORE|RIGHT|AFTER)_HEADER */
 char *htags_options = NULL;
 char *include_file_suffixes = "h,hxx,hpp,H,inc.php";
-static char *langmap = "c:.c,yacc:.y,asm:.s.S,java:.java,cpp:.c++.cc.cpp.cxx.h.hxx.hpp.C.H,php:.php.php3.phtml";
+static char *langmap = DEFAULTLANGMAP;
 
 static struct option const long_options[] = {
         {"alphabet", no_argument, NULL, 'a'},
@@ -375,8 +379,17 @@ generate_file(dist, file)
 			if (i >= tabsize)
 				die("something wrong.");
 			/* print macro value */
-			if (i < tabsize)
-				fputs(tab[i].value, op);
+			if (i < tabsize) {
+				char *q;
+				/*
+				 * Double quote should be quoted using '\\'.
+				 */
+				for (q = tab[i].value; *q; q++) {
+					if (*q == '"')
+						fputc('\\', op);
+					fputc(*q, op);
+				}
+			}
 		}
 		fputs(p, op);
 		fputc('\n', op);
@@ -751,7 +764,7 @@ makehtml(total)
 		snprintf(path, sizeof(path), "%s/%s/%s", distpath, SRCS, p);
 		src2html(_, path, notsource);
 	}
-	if (pclose(ip) < 0)
+	if (pclose(ip) != 0)
 		die("cannot traverse directory.(%s)", command);
 	strbuf_close(sb);
 }
@@ -782,7 +795,8 @@ copyfile(from, to)
 	close(ip);
 }
 /*
- * duplicate file. if possible, link it without making a copy.
+ * duplicate file.
+ * By default, htags uses link system call without making a copy.
  */
 static void
 duplicatefile(file, from, to)
@@ -795,7 +809,7 @@ duplicatefile(file, from, to)
 
 	snprintf(from_path, sizeof(from_path), "%s/%s", from, file);
 	snprintf(to_path, sizeof(to_path), "%s/%s", to, file);
-        if (w32) {
+        if (copy_files) {
                 copyfile(from_path, to_path);
 	} else {
                 if (link(from_path, to_path) < 0)
@@ -867,7 +881,7 @@ makecommonpart(title, defines, files)
 	}
 	strbuf_puts(sb, gen_list_end());
 	strbuf_putc(sb, '\n');
-	if (pclose(ip) < 0)
+	if (pclose(ip) != 0)
 		die("cannot execute command '%s'.", command);
 	strbuf_sprintf(sb, "%s\n", hr);
 	if (aflag && !Fflag) {
@@ -984,7 +998,7 @@ configuration(argc, argv)
 			set_env("GTAGSCONF", real);
 		}
 		if (label)
-			set_env("GTAGSLABEL", gtagslabel);
+			set_env("GTAGSLABEL", label);
 	}
 	/*
 	 * Config variables.
@@ -1040,6 +1054,8 @@ configuration(argc, argv)
 		table_list = 1;
 	if (getconfb("no_order_list"))
 		no_order_list = 1;
+	if (getconfb("copy_files"))
+		copy_files = 1;
 	if (getconfb("no_map_file"))
 		no_map_file = 1;
 	strbuf_reset(sb);
@@ -1300,7 +1316,7 @@ save_environment(argc, argv)
 				strbuf_putc(save_c, *p);
 		}
 	}
-	if (pclose(ip) < 0)
+	if (pclose(ip) != 0)
 		die("cannot execute '%s'.", command);
 	strbuf_close(sb);
 	save_config = strbuf_value(save_c);
@@ -1429,7 +1445,7 @@ main(argc, argv)
 	if (htags_options)
 		argv = append_options(&argc, argv);
 
-	while ((optchar = getopt_long(argc, argv, "acDd:fFgm:noqsS:t:vw", long_options, &option_index)) != EOF) {
+	while ((optchar = getopt_long(argc, argv, "acd:DfFgm:noqsS:t:vw", long_options, &option_index)) != EOF) {
 		switch (optchar) {
                 case 0:
                 case 1:
@@ -1444,9 +1460,9 @@ main(argc, argv)
 			else if (!strcmp("cvsweb-cvsroot", long_options[option_index].name))
                                 cvsweb_cvsroot = optarg;
 			else if (!strcmp("gtagsconf", long_options[option_index].name))
-				strlimcpy(gtagsconf, optarg, sizeof(gtagsconf));
+				;	/*  --gtagsconf is estimated only once. */
 			else if (!strcmp("gtagslabel", long_options[option_index].name))
-                                gtagslabel = optarg;
+				;	/* --gtagslabel is estimated only once. */
 			else if (!strcmp("style-sheet", long_options[option_index].name))
                                 style_sheet = optarg;
                         break;
@@ -1518,6 +1534,13 @@ main(argc, argv)
                 setquiet();
 		vflag = 0;
 	}
+	/*
+	 * If copy_files is true then htags copy tag files instead of linking.
+	 * Since Windows 32 environment doesn't have link system call
+	 * we set copy_files true.
+	 */
+	if (w32)
+		copy_files = 1;
         if (show_version)
                 version(av, vflag);
         if (show_help)
@@ -1625,11 +1648,6 @@ main(argc, argv)
 		if (realpath(dbpath, buf) == NULL)
 			die("cannot get realpath of dbpath.");
 		strlimcpy(dbpath, buf, sizeof(dbpath));
-		if (gtagsconf[0]) {
-			if (realpath(gtagsconf, buf) == NULL)
-				die("cannot get realpath of gtagsconf.");
-			strlimcpy(gtagsconf, buf, sizeof(gtagsconf));
-		}
 	}
 	/*
 	 * for global(1) and gtags(1).
@@ -1637,10 +1655,6 @@ main(argc, argv)
 	set_env("GTAGSROOT", cwdpath);
 	set_env("GTAGSDBPATH", dbpath);
 	set_env("GTAGSLIBPATH", "");
-        if (gtagsconf[0])
-                set_env("GTAGSCONF", gtagsconf);
-        if (gtagslabel)
-                set_env("GTAGSLABEL", gtagslabel);
 	/*
 	 * check directories
 	 */
