@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 1997, 1998, 1999 Shigio Yamaguchi
- * Copyright (c) 1999, 2000, 2001, 2002 Tama Communications Corporation
+ * Copyright (c) 1997, 1998, 1999, 2000, 2001, 2002
+ *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -123,9 +123,9 @@ dbname(db)
  *	o)	sb	command line
  *
  * command skeleton is like this:
- *	'gctags -r %s'
+ *	'gtags-parser -r %s'
  * following skeleton is allowed too.
- *	'gctags -r'
+ *	'gtags-parser -r'
  */
 void
 makecommand(comline, path, sb)
@@ -481,10 +481,12 @@ gtags_add(gtop, comline, path, flags)
 				p++;
 			else if ((p = locatestring(tag, "::", MATCH_LAST)) != NULL)
 				p += 2;
+			else
+				p = tag;
 		}
 		gtags_put(gtop, p, ctags_x);
 	}
-	if (pclose(ip) < 0)
+	if (pclose(ip) != 0)
 		die("terminated abnormally.");
 	strbuf_close(sb);
 	strbuf_close(ib);
