@@ -1,6 +1,6 @@
 /*
- * Copyright (c) 1998, 1999 Shigio Yamaguchi
- * Copyright (c) 1999, 2000, 2002, 2003 Tama Communications Corporation
+ * Copyright (c) 1998, 1999, 2000, 2002, 2003
+ *	Tama Communications Corporation
  *
  * This file is part of GNU GLOBAL.
  *
@@ -60,7 +60,7 @@ static void pushbackchar(void);
  */
 int
 opentoken(file)
-	char *file;
+	const char *file;
 {
 	/*
 	 * b flag is needed for WIN32 environment. Almost unix ignore it.
@@ -74,17 +74,6 @@ opentoken(file)
 	continued_line = 0;
 	return 1;
 }
-/*
- * rewindtoken:
- */
-void
-rewindtoken()
-{
-	sp = cp = lp = NULL; ptok[0] = '\0'; lineno = 0;
-	crflag = cmode = cppmode = ymode = 0;
-	continued_line = 0;
-	rewind(ip);
-}
 /*
  * closetoken:
  */
